context("Decadal monthly data - 2")

###########################################

source("modules/Loading/Loading_decadal.R")
source("modules/Calibration/Calibration.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Save_data.R")

recipe_file <- "tests/recipes/recipe-decadal_monthly_2.yml"

# Load datasets
suppressWarnings({invisible(capture.output(
data <- load_datasets(recipe_file)
))})

#recipe <- read_yaml(recipe_file)
## Calibrate datasets
#suppressWarnings({invisible(capture.output(
#  calibrated_data <- calibrate_datasets(data, recipe)
#))})
#
## Compute skill metrics
#suppressWarnings({invisible(capture.output(
#skill_metrics <- compute_skill_metrics(calibrated_data$hcst, data$obs,
#                                       recipe, na.rm = T, ncores = 4)
#))})

#======================================

test_that("1. Loading", {

expect_equal(
is.list(data),
TRUE
)
expect_equal(
names(data),
c("hcst", "fcst", "obs")
)
expect_equal(
class(data$hcst),
"s2dv_cube"
)
expect_equal(
class(data$fcst),
"s2dv_cube"
)
expect_equal(
class(data$obs),
"s2dv_cube"
)
expect_equal(
names(data$hcst),
c("data", "Variable", "Datasets", "Dates", "when", "source_files", "load_parameters")
)
expect_equal(
names(data$hcst),
names(data$fcst)
)
expect_equal(
names(data$hcst),
names(data$obs)
)
expect_equal(
dim(data$hcst$data),
c(dat = 1, var = 1, ensemble = 3, sday = 1, sweek = 1, syear = 3, time = 14, latitude = 8, longitude = 5)
)
expect_equal(
dim(data$fcst$data),
c(dat = 1, var = 1, ensemble = 3, sday = 1, sweek = 1, syear = 2, time = 14, latitude = 8, longitude = 5)
)
expect_equal(
dim(data$hcst$Dates$start),
c(sday = 1, sweek = 1, syear = 3, time = 14)
)
#expect_equal(
#dim(data$fcst$Dates$start),
#c(time = 14)
#)
# hcst data
expect_equal(
as.vector(drop(data$hcst$data)[1, , 1:2, 2, 2]),
c(272.8613, 271.0689, 270.8007, 273.5594, 272.1561, 272.8729),
tolerance = 0.0001
)
expect_equal(
mean(data$hcst$data),
269.8822,
tolerance = 0.0001
)
expect_equal(
range(data$hcst$data),
c(253.8541, 276.6805),
tolerance = 0.0001
)
# fcst data
expect_equal(
as.vector(drop(data$fcst$data)[1, , 1:2, 2, 2]),
c(271.7708, 271.8424, 272.4980, 273.5842),
tolerance = 0.0001
)
expect_equal(
mean(data$fcst$data),
271.2158,
tolerance = 0.0001
)

expect_equal(
(data$hcst$Dates$start)[1],
as.POSIXct("1990-11-16", tz = 'UTC')
)
expect_equal(
(data$hcst$Dates$start)[2],
as.POSIXct("1991-11-16", tz = 'UTC')
)
expect_equal(
(data$hcst$Dates$start)[5],
as.POSIXct("1991-12-16 12:00:00", tz = 'UTC')
)
expect_equal(
(data$hcst$Dates$start)[10],
as.POSIXct("1991-02-15", tz = 'UTC')
)

})

#======================================
#test_that("2. Calibration", {
#
#expect_equal(
#is.list(calibrated_data),
#TRUE
#)
#expect_equal(
#names(calibrated_data),
#c("hcst", "fcst")
#)
#expect_equal(
#class(calibrated_data$hcst),
#"s2dv_cube"
#)
#expect_equal(
#class(calibrated_data$fcst),
#"s2dv_cube"
#)
#expect_equal(
#dim(calibrated_data$hcst$data),
#c(dat = 1, var = 1, ensemble = 2, sday = 1, sweek = 1, syear = 4, time = 3, latitude = 5, longitude = 4)
#)
#expect_equal(
#dim(calibrated_data$fcst$data),
#c(dat = 1, var = 1, ensemble = 2, sday = 1, sweek = 1, syear = 1, time = 3, latitude = 5, longitude = 4)
#)
#expect_equal(
#mean(calibrated_data$fcst$data),
#291.8375,
#tolerance = 0.0001
#)
#expect_equal(
#mean(calibrated_data$hcst$data),
#289.6679,
#tolerance = 0.0001
#)
#expect_equal(
#as.vector(drop(calibrated_data$hcst$data)[1, , 2, 3, 4]),
#c(286.3895, 286.6408, 290.6652, 288.3759),
#tolerance = 0.0001
#)
#expect_equal(
#range(calibrated_data$fcst$data),
#c(287.2173, 297.4578),
#tolerance = 0.0001
#)
#
#})
#
#
##======================================
#test_that("3. Metrics", {
#
#expect_equal(
#is.list(skill_metrics),
#TRUE
#)
#expect_equal(
#names(skill_metrics),
#c("rpss", "rpss_significance")
#)
#expect_equal(
#class(skill_metrics$rpss[[1]]),
#"array"
#)
#expect_equal(
#dim(skill_metrics$rpss[[1]]),
#c(dat = 1, var = 1, sday = 1, sweek = 1, time = 3, latitude = 5, longitude = 4)
#)
#expect_equal(
#dim(skill_metrics$rpss_significance[[1]]),
#dim(skill_metrics$rpss[[1]])
#)
#expect_equal(
#as.vector(drop(skill_metrics$rpss[[1]])[, 2, 3]),
#c(-0.2857143, -1.2500000, -1.8928571),
#tolerance = 0.0001
#)
#expect_equal(
#as.vector(drop(skill_metrics$rpss_significance[[1]])[, 2, 3]),
#rep(FALSE, 3)
#)
#
#})
#
#
